==> jc-1.4.0.tar.gz: javax/transaction/HeuristicRollbackException.h <==
// public class javax.transaction.HeuristicRollbackException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 13f638e1c422e98c javax_transaction_HeuristicRollbackException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_javax_transaction_HeuristicRollbackException_H_
#define _JC_javax_transaction_HeuristicRollbackException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_transaction_HeuristicRollbackException$sub_refs	_jc_javax_transaction_HeuristicRollbackException$sub_refs;
typedef struct _jc_javax_transaction_HeuristicRollbackException$sub_nonrefs	_jc_javax_transaction_HeuristicRollbackException$sub_nonrefs;
typedef struct _jc_javax_transaction_HeuristicRollbackException$refs	_jc_javax_transaction_HeuristicRollbackException$refs;
typedef struct _jc_javax_transaction_HeuristicRollbackException$nonrefs	_jc_javax_transaction_HeuristicRollbackException$nonrefs;
typedef struct _jc_javax_transaction_HeuristicRollbackException$object	_jc_javax_transaction_HeuristicRollbackException$object;

typedef const struct _jc_javax_transaction_HeuristicRollbackException$vmethods	_jc_javax_transaction_HeuristicRollbackException$vmethods;
typedef const struct _jc_javax_transaction_HeuristicRollbackException$vtable	_jc_javax_transaction_HeuristicRollbackException$vtable;
typedef const struct _jc_javax_transaction_HeuristicRollbackException$vtype	_jc_javax_transaction_HeuristicRollbackException$vtype;

// Constructors
extern void _jc_javax_transaction_HeuristicRollbackException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_transaction_HeuristicRollbackException$object *);
extern void _jc_javax_transaction_HeuristicRollbackException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_transaction_HeuristicRollbackException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_javax_transaction_HeuristicRollbackException$vmethods {
};

// Vtable
struct _jc_javax_transaction_HeuristicRollbackException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_transaction_HeuristicRollbackException$vmethods	javax_transaction_HeuristicRollbackException;
};

// Vtype
struct _jc_javax_transaction_HeuristicRollbackException$vtype {
	_jc_type			type;
	_jc_javax_transaction_HeuristicRollbackException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_transaction_HeuristicRollbackException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_transaction_HeuristicRollbackException$refs {
    _jc_javax_transaction_HeuristicRollbackException$sub_refs	javax_transaction_HeuristicRollbackException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_transaction_HeuristicRollbackException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_transaction_HeuristicRollbackException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_transaction_HeuristicRollbackException$sub_nonrefs	javax_transaction_HeuristicRollbackException;
};

// Object instance structure
struct _jc_javax_transaction_HeuristicRollbackException$object {
	_jc_javax_transaction_HeuristicRollbackException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_transaction_HeuristicRollbackException$vtype	*vtype;
	_jc_javax_transaction_HeuristicRollbackException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_transaction_HeuristicRollbackException$vtype _jc_javax_transaction_HeuristicRollbackException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_transaction_HeuristicRollbackException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_transaction_HeuristicRollbackException$class_object;

#endif	/* _JC_javax_transaction_HeuristicRollbackException_H_ */

==> jc-1.4.6.tar.gz: javax/transaction/HeuristicRollbackException.h <==
// public class javax.transaction.HeuristicRollbackException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 13f638e1c422e98c javax_transaction_HeuristicRollbackException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_javax_transaction_HeuristicRollbackException_H_
#define _JC_javax_transaction_HeuristicRollbackException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_transaction_HeuristicRollbackException$sub_refs	_jc_javax_transaction_HeuristicRollbackException$sub_refs;
typedef struct _jc_javax_transaction_HeuristicRollbackException$sub_nonrefs	_jc_javax_transaction_HeuristicRollbackException$sub_nonrefs;
typedef struct _jc_javax_transaction_HeuristicRollbackException$refs	_jc_javax_transaction_HeuristicRollbackException$refs;
typedef struct _jc_javax_transaction_HeuristicRollbackException$nonrefs	_jc_javax_transaction_HeuristicRollbackException$nonrefs;
typedef struct _jc_javax_transaction_HeuristicRollbackException$object	_jc_javax_transaction_HeuristicRollbackException$object;

typedef const struct _jc_javax_transaction_HeuristicRollbackException$vmethods	_jc_javax_transaction_HeuristicRollbackException$vmethods;
typedef const struct _jc_javax_transaction_HeuristicRollbackException$vtable	_jc_javax_transaction_HeuristicRollbackException$vtable;
typedef const struct _jc_javax_transaction_HeuristicRollbackException$vtype	_jc_javax_transaction_HeuristicRollbackException$vtype;

// Constructors
extern void _jc_javax_transaction_HeuristicRollbackException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_transaction_HeuristicRollbackException$object *) _JC_JCNI_ATTR;
extern void _jc_javax_transaction_HeuristicRollbackException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_transaction_HeuristicRollbackException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_transaction_HeuristicRollbackException$vmethods {
};

// Vtable
struct _jc_javax_transaction_HeuristicRollbackException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_transaction_HeuristicRollbackException$vmethods	javax_transaction_HeuristicRollbackException;
};

// Vtype
struct _jc_javax_transaction_HeuristicRollbackException$vtype {
	_jc_type			type;
	_jc_javax_transaction_HeuristicRollbackException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_transaction_HeuristicRollbackException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_transaction_HeuristicRollbackException$refs {
    _jc_javax_transaction_HeuristicRollbackException$sub_refs	javax_transaction_HeuristicRollbackException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_transaction_HeuristicRollbackException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_transaction_HeuristicRollbackException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_transaction_HeuristicRollbackException$sub_nonrefs	javax_transaction_HeuristicRollbackException;
};

// Object instance structure
struct _jc_javax_transaction_HeuristicRollbackException$object {
	_jc_javax_transaction_HeuristicRollbackException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_transaction_HeuristicRollbackException$vtype	*vtype;
	_jc_javax_transaction_HeuristicRollbackException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_transaction_HeuristicRollbackException$vtype _jc_javax_transaction_HeuristicRollbackException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_transaction_HeuristicRollbackException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_transaction_HeuristicRollbackException$class_object;

#endif	/* _JC_javax_transaction_HeuristicRollbackException_H_ */
